# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApplicationArgs', 'Application']

@pulumi.input_type
class ApplicationArgs:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[bool]] = None,
                 browser_wait_millis: Optional[pulumi.Input[int]] = None,
                 default_config: Optional[pulumi.Input['ApplicationDefaultConfigArgs']] = None,
                 jobs_per_transaction: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Application resource.
        :param pulumi.Input[bool] active: Indicates whether or not this application is currently active and usable for traffic
               steering.
        :param pulumi.Input[int] browser_wait_millis: The amount of time (in milliseconds) the browser should wait before running
               measurements.
        :param pulumi.Input['ApplicationDefaultConfigArgs'] default_config: Default job configuration. If a field is present here and not on a specific job
               associated with this application, the default value specified here is used..
        :param pulumi.Input[int] jobs_per_transaction: Number of jobs to measure per user impression.
        :param pulumi.Input[str] name: Descriptive name for this Pulsar app.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if browser_wait_millis is not None:
            pulumi.set(__self__, "browser_wait_millis", browser_wait_millis)
        if default_config is not None:
            pulumi.set(__self__, "default_config", default_config)
        if jobs_per_transaction is not None:
            pulumi.set(__self__, "jobs_per_transaction", jobs_per_transaction)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not this application is currently active and usable for traffic
        steering.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter(name="browserWaitMillis")
    def browser_wait_millis(self) -> Optional[pulumi.Input[int]]:
        """
        The amount of time (in milliseconds) the browser should wait before running
        measurements.
        """
        return pulumi.get(self, "browser_wait_millis")

    @browser_wait_millis.setter
    def browser_wait_millis(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "browser_wait_millis", value)

    @property
    @pulumi.getter(name="defaultConfig")
    def default_config(self) -> Optional[pulumi.Input['ApplicationDefaultConfigArgs']]:
        """
        Default job configuration. If a field is present here and not on a specific job
        associated with this application, the default value specified here is used..
        """
        return pulumi.get(self, "default_config")

    @default_config.setter
    def default_config(self, value: Optional[pulumi.Input['ApplicationDefaultConfigArgs']]):
        pulumi.set(self, "default_config", value)

    @property
    @pulumi.getter(name="jobsPerTransaction")
    def jobs_per_transaction(self) -> Optional[pulumi.Input[int]]:
        """
        Number of jobs to measure per user impression.
        """
        return pulumi.get(self, "jobs_per_transaction")

    @jobs_per_transaction.setter
    def jobs_per_transaction(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "jobs_per_transaction", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Descriptive name for this Pulsar app.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ApplicationState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[bool]] = None,
                 browser_wait_millis: Optional[pulumi.Input[int]] = None,
                 default_config: Optional[pulumi.Input['ApplicationDefaultConfigArgs']] = None,
                 jobs_per_transaction: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Application resources.
        :param pulumi.Input[bool] active: Indicates whether or not this application is currently active and usable for traffic
               steering.
        :param pulumi.Input[int] browser_wait_millis: The amount of time (in milliseconds) the browser should wait before running
               measurements.
        :param pulumi.Input['ApplicationDefaultConfigArgs'] default_config: Default job configuration. If a field is present here and not on a specific job
               associated with this application, the default value specified here is used..
        :param pulumi.Input[int] jobs_per_transaction: Number of jobs to measure per user impression.
        :param pulumi.Input[str] name: Descriptive name for this Pulsar app.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if browser_wait_millis is not None:
            pulumi.set(__self__, "browser_wait_millis", browser_wait_millis)
        if default_config is not None:
            pulumi.set(__self__, "default_config", default_config)
        if jobs_per_transaction is not None:
            pulumi.set(__self__, "jobs_per_transaction", jobs_per_transaction)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not this application is currently active and usable for traffic
        steering.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter(name="browserWaitMillis")
    def browser_wait_millis(self) -> Optional[pulumi.Input[int]]:
        """
        The amount of time (in milliseconds) the browser should wait before running
        measurements.
        """
        return pulumi.get(self, "browser_wait_millis")

    @browser_wait_millis.setter
    def browser_wait_millis(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "browser_wait_millis", value)

    @property
    @pulumi.getter(name="defaultConfig")
    def default_config(self) -> Optional[pulumi.Input['ApplicationDefaultConfigArgs']]:
        """
        Default job configuration. If a field is present here and not on a specific job
        associated with this application, the default value specified here is used..
        """
        return pulumi.get(self, "default_config")

    @default_config.setter
    def default_config(self, value: Optional[pulumi.Input['ApplicationDefaultConfigArgs']]):
        pulumi.set(self, "default_config", value)

    @property
    @pulumi.getter(name="jobsPerTransaction")
    def jobs_per_transaction(self) -> Optional[pulumi.Input[int]]:
        """
        Number of jobs to measure per user impression.
        """
        return pulumi.get(self, "jobs_per_transaction")

    @jobs_per_transaction.setter
    def jobs_per_transaction(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "jobs_per_transaction", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Descriptive name for this Pulsar app.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class Application(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[bool]] = None,
                 browser_wait_millis: Optional[pulumi.Input[int]] = None,
                 default_config: Optional[pulumi.Input[pulumi.InputType['ApplicationDefaultConfigArgs']]] = None,
                 jobs_per_transaction: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a NS1 Pulsar application resource. This can be used to create, modify, and delete applications.

        ## Import

        ```sh
        $ pulumi import ns1:index/application:Application `ns1_application`
        ```

        So for the example above:

        ```sh
        $ pulumi import ns1:index/application:Application example terraform.example.io`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Indicates whether or not this application is currently active and usable for traffic
               steering.
        :param pulumi.Input[int] browser_wait_millis: The amount of time (in milliseconds) the browser should wait before running
               measurements.
        :param pulumi.Input[pulumi.InputType['ApplicationDefaultConfigArgs']] default_config: Default job configuration. If a field is present here and not on a specific job
               associated with this application, the default value specified here is used..
        :param pulumi.Input[int] jobs_per_transaction: Number of jobs to measure per user impression.
        :param pulumi.Input[str] name: Descriptive name for this Pulsar app.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ApplicationArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a NS1 Pulsar application resource. This can be used to create, modify, and delete applications.

        ## Import

        ```sh
        $ pulumi import ns1:index/application:Application `ns1_application`
        ```

        So for the example above:

        ```sh
        $ pulumi import ns1:index/application:Application example terraform.example.io`
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[bool]] = None,
                 browser_wait_millis: Optional[pulumi.Input[int]] = None,
                 default_config: Optional[pulumi.Input[pulumi.InputType['ApplicationDefaultConfigArgs']]] = None,
                 jobs_per_transaction: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationArgs.__new__(ApplicationArgs)

            __props__.__dict__["active"] = active
            __props__.__dict__["browser_wait_millis"] = browser_wait_millis
            __props__.__dict__["default_config"] = default_config
            __props__.__dict__["jobs_per_transaction"] = jobs_per_transaction
            __props__.__dict__["name"] = name
        super(Application, __self__).__init__(
            'ns1:index/application:Application',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[bool]] = None,
            browser_wait_millis: Optional[pulumi.Input[int]] = None,
            default_config: Optional[pulumi.Input[pulumi.InputType['ApplicationDefaultConfigArgs']]] = None,
            jobs_per_transaction: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'Application':
        """
        Get an existing Application resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Indicates whether or not this application is currently active and usable for traffic
               steering.
        :param pulumi.Input[int] browser_wait_millis: The amount of time (in milliseconds) the browser should wait before running
               measurements.
        :param pulumi.Input[pulumi.InputType['ApplicationDefaultConfigArgs']] default_config: Default job configuration. If a field is present here and not on a specific job
               associated with this application, the default value specified here is used..
        :param pulumi.Input[int] jobs_per_transaction: Number of jobs to measure per user impression.
        :param pulumi.Input[str] name: Descriptive name for this Pulsar app.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationState.__new__(_ApplicationState)

        __props__.__dict__["active"] = active
        __props__.__dict__["browser_wait_millis"] = browser_wait_millis
        __props__.__dict__["default_config"] = default_config
        __props__.__dict__["jobs_per_transaction"] = jobs_per_transaction
        __props__.__dict__["name"] = name
        return Application(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether or not this application is currently active and usable for traffic
        steering.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="browserWaitMillis")
    def browser_wait_millis(self) -> pulumi.Output[Optional[int]]:
        """
        The amount of time (in milliseconds) the browser should wait before running
        measurements.
        """
        return pulumi.get(self, "browser_wait_millis")

    @property
    @pulumi.getter(name="defaultConfig")
    def default_config(self) -> pulumi.Output['outputs.ApplicationDefaultConfig']:
        """
        Default job configuration. If a field is present here and not on a specific job
        associated with this application, the default value specified here is used..
        """
        return pulumi.get(self, "default_config")

    @property
    @pulumi.getter(name="jobsPerTransaction")
    def jobs_per_transaction(self) -> pulumi.Output[Optional[int]]:
        """
        Number of jobs to measure per user impression.
        """
        return pulumi.get(self, "jobs_per_transaction")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Descriptive name for this Pulsar app.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NotifyListArgs', 'NotifyList']

@pulumi.input_type
class NotifyListArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 notifications: Optional[pulumi.Input[Sequence[pulumi.Input['NotifyListNotificationArgs']]]] = None):
        """
        The set of arguments for constructing a NotifyList resource.
        :param pulumi.Input[str] name: The free-form display name for the notify list.
        :param pulumi.Input[Sequence[pulumi.Input['NotifyListNotificationArgs']]] notifications: A list of notifiers. All notifiers in a notification list will receive notifications whenever an event is send to the list (e.g., when a monitoring job fails). Notifiers are documented below.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notifications is not None:
            pulumi.set(__self__, "notifications", notifications)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The free-form display name for the notify list.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def notifications(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NotifyListNotificationArgs']]]]:
        """
        A list of notifiers. All notifiers in a notification list will receive notifications whenever an event is send to the list (e.g., when a monitoring job fails). Notifiers are documented below.
        """
        return pulumi.get(self, "notifications")

    @notifications.setter
    def notifications(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NotifyListNotificationArgs']]]]):
        pulumi.set(self, "notifications", value)


@pulumi.input_type
class _NotifyListState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 notifications: Optional[pulumi.Input[Sequence[pulumi.Input['NotifyListNotificationArgs']]]] = None):
        """
        Input properties used for looking up and filtering NotifyList resources.
        :param pulumi.Input[str] name: The free-form display name for the notify list.
        :param pulumi.Input[Sequence[pulumi.Input['NotifyListNotificationArgs']]] notifications: A list of notifiers. All notifiers in a notification list will receive notifications whenever an event is send to the list (e.g., when a monitoring job fails). Notifiers are documented below.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notifications is not None:
            pulumi.set(__self__, "notifications", notifications)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The free-form display name for the notify list.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def notifications(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NotifyListNotificationArgs']]]]:
        """
        A list of notifiers. All notifiers in a notification list will receive notifications whenever an event is send to the list (e.g., when a monitoring job fails). Notifiers are documented below.
        """
        return pulumi.get(self, "notifications")

    @notifications.setter
    def notifications(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NotifyListNotificationArgs']]]]):
        pulumi.set(self, "notifications", value)


class NotifyList(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notifications: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NotifyListNotificationArgs']]]]] = None,
                 __props__=None):
        """
        Provides a NS1 Notify List resource. This can be used to create, modify, and delete notify lists.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ns1 as ns1

        nl = ns1.NotifyList("nl",
            name="my notify list",
            notifications=[
                ns1.NotifyListNotificationArgs(
                    type="webhook",
                    config={
                        "url": "http://www.mywebhook.com",
                    },
                ),
                ns1.NotifyListNotificationArgs(
                    type="email",
                    config={
                        "email": "test@test.com",
                    },
                ),
            ])
        ```

        ## NS1 Documentation

        [NotifyList Api Doc](https://ns1.com/api#notification-lists)

        ## Import

        ```sh
        $ pulumi import ns1:index/notifyList:NotifyList <name> <notifylist_id>`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The free-form display name for the notify list.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NotifyListNotificationArgs']]]] notifications: A list of notifiers. All notifiers in a notification list will receive notifications whenever an event is send to the list (e.g., when a monitoring job fails). Notifiers are documented below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[NotifyListArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a NS1 Notify List resource. This can be used to create, modify, and delete notify lists.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ns1 as ns1

        nl = ns1.NotifyList("nl",
            name="my notify list",
            notifications=[
                ns1.NotifyListNotificationArgs(
                    type="webhook",
                    config={
                        "url": "http://www.mywebhook.com",
                    },
                ),
                ns1.NotifyListNotificationArgs(
                    type="email",
                    config={
                        "email": "test@test.com",
                    },
                ),
            ])
        ```

        ## NS1 Documentation

        [NotifyList Api Doc](https://ns1.com/api#notification-lists)

        ## Import

        ```sh
        $ pulumi import ns1:index/notifyList:NotifyList <name> <notifylist_id>`
        ```

        :param str resource_name: The name of the resource.
        :param NotifyListArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NotifyListArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notifications: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NotifyListNotificationArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NotifyListArgs.__new__(NotifyListArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["notifications"] = notifications
        super(NotifyList, __self__).__init__(
            'ns1:index/notifyList:NotifyList',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None,
            notifications: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NotifyListNotificationArgs']]]]] = None) -> 'NotifyList':
        """
        Get an existing NotifyList resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The free-form display name for the notify list.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['NotifyListNotificationArgs']]]] notifications: A list of notifiers. All notifiers in a notification list will receive notifications whenever an event is send to the list (e.g., when a monitoring job fails). Notifiers are documented below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NotifyListState.__new__(_NotifyListState)

        __props__.__dict__["name"] = name
        __props__.__dict__["notifications"] = notifications
        return NotifyList(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The free-form display name for the notify list.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def notifications(self) -> pulumi.Output[Optional[Sequence['outputs.NotifyListNotification']]]:
        """
        A list of notifiers. All notifiers in a notification list will receive notifications whenever an event is send to the list (e.g., when a monitoring job fails). Notifiers are documented below.
        """
        return pulumi.get(self, "notifications")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetZoneResult',
    'AwaitableGetZoneResult',
    'get_zone',
    'get_zone_output',
]

@pulumi.output_type
class GetZoneResult:
    """
    A collection of values returned by getZone.
    """
    def __init__(__self__, additional_ports=None, additional_primaries=None, dns_servers=None, dnssec=None, expiry=None, hostmaster=None, id=None, link=None, networks=None, nx_ttl=None, primary=None, primary_port=None, refresh=None, retry=None, secondaries=None, tags=None, ttl=None, zone=None):
        if additional_ports and not isinstance(additional_ports, list):
            raise TypeError("Expected argument 'additional_ports' to be a list")
        pulumi.set(__self__, "additional_ports", additional_ports)
        if additional_primaries and not isinstance(additional_primaries, list):
            raise TypeError("Expected argument 'additional_primaries' to be a list")
        pulumi.set(__self__, "additional_primaries", additional_primaries)
        if dns_servers and not isinstance(dns_servers, str):
            raise TypeError("Expected argument 'dns_servers' to be a str")
        pulumi.set(__self__, "dns_servers", dns_servers)
        if dnssec and not isinstance(dnssec, bool):
            raise TypeError("Expected argument 'dnssec' to be a bool")
        pulumi.set(__self__, "dnssec", dnssec)
        if expiry and not isinstance(expiry, int):
            raise TypeError("Expected argument 'expiry' to be a int")
        pulumi.set(__self__, "expiry", expiry)
        if hostmaster and not isinstance(hostmaster, str):
            raise TypeError("Expected argument 'hostmaster' to be a str")
        pulumi.set(__self__, "hostmaster", hostmaster)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if link and not isinstance(link, str):
            raise TypeError("Expected argument 'link' to be a str")
        pulumi.set(__self__, "link", link)
        if networks and not isinstance(networks, list):
            raise TypeError("Expected argument 'networks' to be a list")
        pulumi.set(__self__, "networks", networks)
        if nx_ttl and not isinstance(nx_ttl, int):
            raise TypeError("Expected argument 'nx_ttl' to be a int")
        pulumi.set(__self__, "nx_ttl", nx_ttl)
        if primary and not isinstance(primary, str):
            raise TypeError("Expected argument 'primary' to be a str")
        pulumi.set(__self__, "primary", primary)
        if primary_port and not isinstance(primary_port, int):
            raise TypeError("Expected argument 'primary_port' to be a int")
        pulumi.set(__self__, "primary_port", primary_port)
        if refresh and not isinstance(refresh, int):
            raise TypeError("Expected argument 'refresh' to be a int")
        pulumi.set(__self__, "refresh", refresh)
        if retry and not isinstance(retry, int):
            raise TypeError("Expected argument 'retry' to be a int")
        pulumi.set(__self__, "retry", retry)
        if secondaries and not isinstance(secondaries, list):
            raise TypeError("Expected argument 'secondaries' to be a list")
        pulumi.set(__self__, "secondaries", secondaries)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if ttl and not isinstance(ttl, int):
            raise TypeError("Expected argument 'ttl' to be a int")
        pulumi.set(__self__, "ttl", ttl)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter(name="additionalPorts")
    def additional_ports(self) -> Optional[Sequence[int]]:
        return pulumi.get(self, "additional_ports")

    @property
    @pulumi.getter(name="additionalPrimaries")
    def additional_primaries(self) -> Optional[Sequence[str]]:
        """
        List of additional IPv4 addresses for the primary
        zone.
        """
        return pulumi.get(self, "additional_primaries")

    @property
    @pulumi.getter(name="dnsServers")
    def dns_servers(self) -> str:
        """
        Authoritative Name Servers.
        """
        return pulumi.get(self, "dns_servers")

    @property
    @pulumi.getter
    def dnssec(self) -> bool:
        """
        Whether or not DNSSEC is enabled for the zone.
        """
        return pulumi.get(self, "dnssec")

    @property
    @pulumi.getter
    def expiry(self) -> int:
        """
        The SOA Expiry.
        """
        return pulumi.get(self, "expiry")

    @property
    @pulumi.getter
    def hostmaster(self) -> str:
        """
        The SOA Hostmaster.
        """
        return pulumi.get(self, "hostmaster")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def link(self) -> str:
        """
        The linked target zone.
        """
        return pulumi.get(self, "link")

    @property
    @pulumi.getter
    def networks(self) -> Sequence[int]:
        """
        List of network IDs (`int`) for which the zone should be made
        available. Default is network 0, the primary NSONE Global Network.
        """
        return pulumi.get(self, "networks")

    @property
    @pulumi.getter(name="nxTtl")
    def nx_ttl(self) -> int:
        """
        The SOA NX TTL.
        """
        return pulumi.get(self, "nx_ttl")

    @property
    @pulumi.getter
    def primary(self) -> str:
        """
        The primary zones' IPv4 address.
        """
        return pulumi.get(self, "primary")

    @property
    @pulumi.getter(name="primaryPort")
    def primary_port(self) -> Optional[int]:
        return pulumi.get(self, "primary_port")

    @property
    @pulumi.getter
    def refresh(self) -> int:
        """
        The SOA Refresh.
        """
        return pulumi.get(self, "refresh")

    @property
    @pulumi.getter
    def retry(self) -> int:
        """
        The SOA Retry.
        """
        return pulumi.get(self, "retry")

    @property
    @pulumi.getter
    def secondaries(self) -> Sequence['outputs.GetZoneSecondaryResult']:
        """
        List of secondary servers. Secondaries is
        documented below.
        """
        return pulumi.get(self, "secondaries")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, Any]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def ttl(self) -> int:
        """
        The SOA TTL.
        """
        return pulumi.get(self, "ttl")

    @property
    @pulumi.getter
    def zone(self) -> str:
        return pulumi.get(self, "zone")


class AwaitableGetZoneResult(GetZoneResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetZoneResult(
            additional_ports=self.additional_ports,
            additional_primaries=self.additional_primaries,
            dns_servers=self.dns_servers,
            dnssec=self.dnssec,
            expiry=self.expiry,
            hostmaster=self.hostmaster,
            id=self.id,
            link=self.link,
            networks=self.networks,
            nx_ttl=self.nx_ttl,
            primary=self.primary,
            primary_port=self.primary_port,
            refresh=self.refresh,
            retry=self.retry,
            secondaries=self.secondaries,
            tags=self.tags,
            ttl=self.ttl,
            zone=self.zone)


def get_zone(additional_ports: Optional[Sequence[int]] = None,
             additional_primaries: Optional[Sequence[str]] = None,
             primary_port: Optional[int] = None,
             zone: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetZoneResult:
    """
    Provides details about a NS1 Zone. Use this if you would simply like to read
    information from NS1 into your configurations. For read/write operations, you
    should use a resource.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ns1 as ns1

    # Get details about a NS1 Zone.
    example = ns1.get_zone(zone="terraform.example.io")
    ```


    :param Sequence[str] additional_primaries: List of additional IPv4 addresses for the primary
           zone.
    :param str zone: The domain name of the zone.
    """
    __args__ = dict()
    __args__['additionalPorts'] = additional_ports
    __args__['additionalPrimaries'] = additional_primaries
    __args__['primaryPort'] = primary_port
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ns1:index/getZone:getZone', __args__, opts=opts, typ=GetZoneResult).value

    return AwaitableGetZoneResult(
        additional_ports=pulumi.get(__ret__, 'additional_ports'),
        additional_primaries=pulumi.get(__ret__, 'additional_primaries'),
        dns_servers=pulumi.get(__ret__, 'dns_servers'),
        dnssec=pulumi.get(__ret__, 'dnssec'),
        expiry=pulumi.get(__ret__, 'expiry'),
        hostmaster=pulumi.get(__ret__, 'hostmaster'),
        id=pulumi.get(__ret__, 'id'),
        link=pulumi.get(__ret__, 'link'),
        networks=pulumi.get(__ret__, 'networks'),
        nx_ttl=pulumi.get(__ret__, 'nx_ttl'),
        primary=pulumi.get(__ret__, 'primary'),
        primary_port=pulumi.get(__ret__, 'primary_port'),
        refresh=pulumi.get(__ret__, 'refresh'),
        retry=pulumi.get(__ret__, 'retry'),
        secondaries=pulumi.get(__ret__, 'secondaries'),
        tags=pulumi.get(__ret__, 'tags'),
        ttl=pulumi.get(__ret__, 'ttl'),
        zone=pulumi.get(__ret__, 'zone'))


@_utilities.lift_output_func(get_zone)
def get_zone_output(additional_ports: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                    additional_primaries: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                    primary_port: Optional[pulumi.Input[Optional[int]]] = None,
                    zone: Optional[pulumi.Input[str]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetZoneResult]:
    """
    Provides details about a NS1 Zone. Use this if you would simply like to read
    information from NS1 into your configurations. For read/write operations, you
    should use a resource.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ns1 as ns1

    # Get details about a NS1 Zone.
    example = ns1.get_zone(zone="terraform.example.io")
    ```


    :param Sequence[str] additional_primaries: List of additional IPv4 addresses for the primary
           zone.
    :param str zone: The domain name of the zone.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 apikey: Optional[pulumi.Input[str]] = None,
                 enable_ddi: Optional[pulumi.Input[bool]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 ignore_ssl: Optional[pulumi.Input[bool]] = None,
                 rate_limit_parallelism: Optional[pulumi.Input[int]] = None,
                 retry_max: Optional[pulumi.Input[int]] = None,
                 user_agent: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[str] apikey: The ns1 API key (required)
        :param pulumi.Input[bool] enable_ddi: Deprecated, no longer in use
        :param pulumi.Input[str] endpoint: URL prefix (including version) for API calls
        :param pulumi.Input[bool] ignore_ssl: Don't validate server SSL/TLS certificate
        :param pulumi.Input[int] rate_limit_parallelism: Tune response to rate limits, see docs
        :param pulumi.Input[int] retry_max: Maximum retries for 50x errors (-1 to disable)
        :param pulumi.Input[str] user_agent: User-Agent string to use in NS1 API requests
        """
        if apikey is not None:
            pulumi.set(__self__, "apikey", apikey)
        if enable_ddi is not None:
            pulumi.set(__self__, "enable_ddi", enable_ddi)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if ignore_ssl is not None:
            pulumi.set(__self__, "ignore_ssl", ignore_ssl)
        if rate_limit_parallelism is not None:
            pulumi.set(__self__, "rate_limit_parallelism", rate_limit_parallelism)
        if retry_max is not None:
            pulumi.set(__self__, "retry_max", retry_max)
        if user_agent is not None:
            pulumi.set(__self__, "user_agent", user_agent)

    @property
    @pulumi.getter
    def apikey(self) -> Optional[pulumi.Input[str]]:
        """
        The ns1 API key (required)
        """
        return pulumi.get(self, "apikey")

    @apikey.setter
    def apikey(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "apikey", value)

    @property
    @pulumi.getter(name="enableDdi")
    def enable_ddi(self) -> Optional[pulumi.Input[bool]]:
        """
        Deprecated, no longer in use
        """
        return pulumi.get(self, "enable_ddi")

    @enable_ddi.setter
    def enable_ddi(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_ddi", value)

    @property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        URL prefix (including version) for API calls
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint", value)

    @property
    @pulumi.getter(name="ignoreSsl")
    def ignore_ssl(self) -> Optional[pulumi.Input[bool]]:
        """
        Don't validate server SSL/TLS certificate
        """
        return pulumi.get(self, "ignore_ssl")

    @ignore_ssl.setter
    def ignore_ssl(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ignore_ssl", value)

    @property
    @pulumi.getter(name="rateLimitParallelism")
    def rate_limit_parallelism(self) -> Optional[pulumi.Input[int]]:
        """
        Tune response to rate limits, see docs
        """
        return pulumi.get(self, "rate_limit_parallelism")

    @rate_limit_parallelism.setter
    def rate_limit_parallelism(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "rate_limit_parallelism", value)

    @property
    @pulumi.getter(name="retryMax")
    def retry_max(self) -> Optional[pulumi.Input[int]]:
        """
        Maximum retries for 50x errors (-1 to disable)
        """
        return pulumi.get(self, "retry_max")

    @retry_max.setter
    def retry_max(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "retry_max", value)

    @property
    @pulumi.getter(name="userAgent")
    def user_agent(self) -> Optional[pulumi.Input[str]]:
        """
        User-Agent string to use in NS1 API requests
        """
        return pulumi.get(self, "user_agent")

    @user_agent.setter
    def user_agent(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_agent", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 apikey: Optional[pulumi.Input[str]] = None,
                 enable_ddi: Optional[pulumi.Input[bool]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 ignore_ssl: Optional[pulumi.Input[bool]] = None,
                 rate_limit_parallelism: Optional[pulumi.Input[int]] = None,
                 retry_max: Optional[pulumi.Input[int]] = None,
                 user_agent: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The provider type for the ns1 package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] apikey: The ns1 API key (required)
        :param pulumi.Input[bool] enable_ddi: Deprecated, no longer in use
        :param pulumi.Input[str] endpoint: URL prefix (including version) for API calls
        :param pulumi.Input[bool] ignore_ssl: Don't validate server SSL/TLS certificate
        :param pulumi.Input[int] rate_limit_parallelism: Tune response to rate limits, see docs
        :param pulumi.Input[int] retry_max: Maximum retries for 50x errors (-1 to disable)
        :param pulumi.Input[str] user_agent: User-Agent string to use in NS1 API requests
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the ns1 package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 apikey: Optional[pulumi.Input[str]] = None,
                 enable_ddi: Optional[pulumi.Input[bool]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 ignore_ssl: Optional[pulumi.Input[bool]] = None,
                 rate_limit_parallelism: Optional[pulumi.Input[int]] = None,
                 retry_max: Optional[pulumi.Input[int]] = None,
                 user_agent: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["apikey"] = apikey
            __props__.__dict__["enable_ddi"] = pulumi.Output.from_input(enable_ddi).apply(pulumi.runtime.to_json) if enable_ddi is not None else None
            __props__.__dict__["endpoint"] = endpoint
            __props__.__dict__["ignore_ssl"] = pulumi.Output.from_input(ignore_ssl).apply(pulumi.runtime.to_json) if ignore_ssl is not None else None
            __props__.__dict__["rate_limit_parallelism"] = pulumi.Output.from_input(rate_limit_parallelism).apply(pulumi.runtime.to_json) if rate_limit_parallelism is not None else None
            __props__.__dict__["retry_max"] = pulumi.Output.from_input(retry_max).apply(pulumi.runtime.to_json) if retry_max is not None else None
            __props__.__dict__["user_agent"] = user_agent
        super(Provider, __self__).__init__(
            'ns1',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter
    def apikey(self) -> pulumi.Output[Optional[str]]:
        """
        The ns1 API key (required)
        """
        return pulumi.get(self, "apikey")

    @property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output[Optional[str]]:
        """
        URL prefix (including version) for API calls
        """
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter(name="userAgent")
    def user_agent(self) -> pulumi.Output[Optional[str]]:
        """
        User-Agent string to use in NS1 API requests
        """
        return pulumi.get(self, "user_agent")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'APIKeyDnsRecordsAllowArgs',
    'APIKeyDnsRecordsDenyArgs',
    'ApplicationDefaultConfigArgs',
    'DatasetDatatypeArgs',
    'DatasetRepeatArgs',
    'DatasetReportArgs',
    'DatasetTimeframeArgs',
    'MonitoringJobRuleArgs',
    'NotifyListNotificationArgs',
    'PulsarJobBlendMetricWeightsArgs',
    'PulsarJobConfigArgs',
    'PulsarJobWeightArgs',
    'RecordAnswerArgs',
    'RecordFilterArgs',
    'RecordRegionArgs',
    'TeamDnsRecordsAllowArgs',
    'TeamDnsRecordsDenyArgs',
    'TeamIpWhitelistArgs',
    'UserDnsRecordsAllowArgs',
    'UserDnsRecordsDenyArgs',
    'ZoneSecondaryArgs',
    'GetMonitoringRegionsRegionArgs',
]

@pulumi.input_type
class APIKeyDnsRecordsAllowArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[str],
                 include_subdomains: pulumi.Input[bool],
                 type: pulumi.Input[str],
                 zone: pulumi.Input[str]):
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "include_subdomains", include_subdomains)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="includeSubdomains")
    def include_subdomains(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "include_subdomains")

    @include_subdomains.setter
    def include_subdomains(self, value: pulumi.Input[bool]):
        pulumi.set(self, "include_subdomains", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[str]:
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class APIKeyDnsRecordsDenyArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[str],
                 include_subdomains: pulumi.Input[bool],
                 type: pulumi.Input[str],
                 zone: pulumi.Input[str]):
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "include_subdomains", include_subdomains)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="includeSubdomains")
    def include_subdomains(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "include_subdomains")

    @include_subdomains.setter
    def include_subdomains(self, value: pulumi.Input[bool]):
        pulumi.set(self, "include_subdomains", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[str]:
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class ApplicationDefaultConfigArgs:
    def __init__(__self__, *,
                 http: pulumi.Input[bool],
                 https: Optional[pulumi.Input[bool]] = None,
                 job_timeout_millis: Optional[pulumi.Input[int]] = None,
                 request_timeout_millis: Optional[pulumi.Input[int]] = None,
                 static_values: Optional[pulumi.Input[bool]] = None,
                 use_xhr: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[bool] http: Indicates whether or not to use HTTP in measurements.
        :param pulumi.Input[bool] https: Indicates whether or not to use HTTPS in measurements.
        :param pulumi.Input[int] job_timeout_millis: Maximum timeout per job
               0, the primary NSONE Global Network. Normally, you should not have to worry about this.
        :param pulumi.Input[int] request_timeout_millis: Maximum timeout per request.
        :param pulumi.Input[bool] static_values: Indicates whether or not to skip aggregation for this job's measurements
        :param pulumi.Input[bool] use_xhr: Whether to use XMLHttpRequest (XHR) when taking measurements.
        """
        pulumi.set(__self__, "http", http)
        if https is not None:
            pulumi.set(__self__, "https", https)
        if job_timeout_millis is not None:
            pulumi.set(__self__, "job_timeout_millis", job_timeout_millis)
        if request_timeout_millis is not None:
            pulumi.set(__self__, "request_timeout_millis", request_timeout_millis)
        if static_values is not None:
            pulumi.set(__self__, "static_values", static_values)
        if use_xhr is not None:
            pulumi.set(__self__, "use_xhr", use_xhr)

    @property
    @pulumi.getter
    def http(self) -> pulumi.Input[bool]:
        """
        Indicates whether or not to use HTTP in measurements.
        """
        return pulumi.get(self, "http")

    @http.setter
    def http(self, value: pulumi.Input[bool]):
        pulumi.set(self, "http", value)

    @property
    @pulumi.getter
    def https(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not to use HTTPS in measurements.
        """
        return pulumi.get(self, "https")

    @https.setter
    def https(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "https", value)

    @property
    @pulumi.getter(name="jobTimeoutMillis")
    def job_timeout_millis(self) -> Optional[pulumi.Input[int]]:
        """
        Maximum timeout per job
        0, the primary NSONE Global Network. Normally, you should not have to worry about this.
        """
        return pulumi.get(self, "job_timeout_millis")

    @job_timeout_millis.setter
    def job_timeout_millis(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "job_timeout_millis", value)

    @property
    @pulumi.getter(name="requestTimeoutMillis")
    def request_timeout_millis(self) -> Optional[pulumi.Input[int]]:
        """
        Maximum timeout per request.
        """
        return pulumi.get(self, "request_timeout_millis")

    @request_timeout_millis.setter
    def request_timeout_millis(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "request_timeout_millis", value)

    @property
    @pulumi.getter(name="staticValues")
    def static_values(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not to skip aggregation for this job's measurements
        """
        return pulumi.get(self, "static_values")

    @static_values.setter
    def static_values(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "static_values", value)

    @property
    @pulumi.getter(name="useXhr")
    def use_xhr(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to use XMLHttpRequest (XHR) when taking measurements.
        """
        return pulumi.get(self, "use_xhr")

    @use_xhr.setter
    def use_xhr(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_xhr", value)


@pulumi.input_type
class DatasetDatatypeArgs:
    def __init__(__self__, *,
                 data: pulumi.Input[Mapping[str, Any]],
                 scope: pulumi.Input[str],
                 type: pulumi.Input[str]):
        pulumi.set(__self__, "data", data)
        pulumi.set(__self__, "scope", scope)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def data(self) -> pulumi.Input[Mapping[str, Any]]:
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: pulumi.Input[Mapping[str, Any]]):
        pulumi.set(self, "data", value)

    @property
    @pulumi.getter
    def scope(self) -> pulumi.Input[str]:
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: pulumi.Input[str]):
        pulumi.set(self, "scope", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class DatasetRepeatArgs:
    def __init__(__self__, *,
                 end_after_n: pulumi.Input[int],
                 repeats_every: pulumi.Input[str],
                 start: pulumi.Input[int]):
        pulumi.set(__self__, "end_after_n", end_after_n)
        pulumi.set(__self__, "repeats_every", repeats_every)
        pulumi.set(__self__, "start", start)

    @property
    @pulumi.getter(name="endAfterN")
    def end_after_n(self) -> pulumi.Input[int]:
        return pulumi.get(self, "end_after_n")

    @end_after_n.setter
    def end_after_n(self, value: pulumi.Input[int]):
        pulumi.set(self, "end_after_n", value)

    @property
    @pulumi.getter(name="repeatsEvery")
    def repeats_every(self) -> pulumi.Input[str]:
        return pulumi.get(self, "repeats_every")

    @repeats_every.setter
    def repeats_every(self, value: pulumi.Input[str]):
        pulumi.set(self, "repeats_every", value)

    @property
    @pulumi.getter
    def start(self) -> pulumi.Input[int]:
        return pulumi.get(self, "start")

    @start.setter
    def start(self, value: pulumi.Input[int]):
        pulumi.set(self, "start", value)


@pulumi.input_type
class DatasetReportArgs:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[int]] = None,
                 end: Optional[pulumi.Input[int]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 start: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if end is not None:
            pulumi.set(__self__, "end", end)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if start is not None:
            pulumi.set(__self__, "start", start)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def end(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "end")

    @end.setter
    def end(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "end", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def start(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "start")

    @start.setter
    def start(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "start", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class DatasetTimeframeArgs:
    def __init__(__self__, *,
                 aggregation: pulumi.Input[str],
                 cycles: Optional[pulumi.Input[int]] = None,
                 from_: Optional[pulumi.Input[int]] = None,
                 to: Optional[pulumi.Input[int]] = None):
        pulumi.set(__self__, "aggregation", aggregation)
        if cycles is not None:
            pulumi.set(__self__, "cycles", cycles)
        if from_ is not None:
            pulumi.set(__self__, "from_", from_)
        if to is not None:
            pulumi.set(__self__, "to", to)

    @property
    @pulumi.getter
    def aggregation(self) -> pulumi.Input[str]:
        return pulumi.get(self, "aggregation")

    @aggregation.setter
    def aggregation(self, value: pulumi.Input[str]):
        pulumi.set(self, "aggregation", value)

    @property
    @pulumi.getter
    def cycles(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "cycles")

    @cycles.setter
    def cycles(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cycles", value)

    @property
    @pulumi.getter(name="from")
    def from_(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "from_")

    @from_.setter
    def from_(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "from_", value)

    @property
    @pulumi.getter
    def to(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "to")

    @to.setter
    def to(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "to", value)


@pulumi.input_type
class MonitoringJobRuleArgs:
    def __init__(__self__, *,
                 comparison: pulumi.Input[str],
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        pulumi.set(__self__, "comparison", comparison)
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def comparison(self) -> pulumi.Input[str]:
        return pulumi.get(self, "comparison")

    @comparison.setter
    def comparison(self, value: pulumi.Input[str]):
        pulumi.set(self, "comparison", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class NotifyListNotificationArgs:
    def __init__(__self__, *,
                 config: pulumi.Input[Mapping[str, Any]],
                 type: pulumi.Input[str]):
        """
        :param pulumi.Input[Mapping[str, Any]] config: Configuration details for the given notifier type.
        :param pulumi.Input[str] type: The type of notifier. Available notifiers are indicated in /notifytypes endpoint.
        """
        pulumi.set(__self__, "config", config)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def config(self) -> pulumi.Input[Mapping[str, Any]]:
        """
        Configuration details for the given notifier type.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: pulumi.Input[Mapping[str, Any]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The type of notifier. Available notifiers are indicated in /notifytypes endpoint.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class PulsarJobBlendMetricWeightsArgs:
    def __init__(__self__, *,
                 timestamp: pulumi.Input[int]):
        pulumi.set(__self__, "timestamp", timestamp)

    @property
    @pulumi.getter
    def timestamp(self) -> pulumi.Input[int]:
        return pulumi.get(self, "timestamp")

    @timestamp.setter
    def timestamp(self, value: pulumi.Input[int]):
        pulumi.set(self, "timestamp", value)


@pulumi.input_type
class PulsarJobConfigArgs:
    def __init__(__self__, *,
                 host: Optional[pulumi.Input[str]] = None,
                 http: Optional[pulumi.Input[bool]] = None,
                 https: Optional[pulumi.Input[bool]] = None,
                 job_timeout_millis: Optional[pulumi.Input[int]] = None,
                 request_timeout_millis: Optional[pulumi.Input[int]] = None,
                 static_values: Optional[pulumi.Input[bool]] = None,
                 url_path: Optional[pulumi.Input[str]] = None,
                 use_xhr: Optional[pulumi.Input[bool]] = None):
        if host is not None:
            pulumi.set(__self__, "host", host)
        if http is not None:
            pulumi.set(__self__, "http", http)
        if https is not None:
            pulumi.set(__self__, "https", https)
        if job_timeout_millis is not None:
            pulumi.set(__self__, "job_timeout_millis", job_timeout_millis)
        if request_timeout_millis is not None:
            pulumi.set(__self__, "request_timeout_millis", request_timeout_millis)
        if static_values is not None:
            pulumi.set(__self__, "static_values", static_values)
        if url_path is not None:
            pulumi.set(__self__, "url_path", url_path)
        if use_xhr is not None:
            pulumi.set(__self__, "use_xhr", use_xhr)

    @property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter
    def http(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "http")

    @http.setter
    def http(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "http", value)

    @property
    @pulumi.getter
    def https(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "https")

    @https.setter
    def https(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "https", value)

    @property
    @pulumi.getter(name="jobTimeoutMillis")
    def job_timeout_millis(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "job_timeout_millis")

    @job_timeout_millis.setter
    def job_timeout_millis(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "job_timeout_millis", value)

    @property
    @pulumi.getter(name="requestTimeoutMillis")
    def request_timeout_millis(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "request_timeout_millis")

    @request_timeout_millis.setter
    def request_timeout_millis(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "request_timeout_millis", value)

    @property
    @pulumi.getter(name="staticValues")
    def static_values(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "static_values")

    @static_values.setter
    def static_values(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "static_values", value)

    @property
    @pulumi.getter(name="urlPath")
    def url_path(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "url_path")

    @url_path.setter
    def url_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url_path", value)

    @property
    @pulumi.getter(name="useXhr")
    def use_xhr(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "use_xhr")

    @use_xhr.setter
    def use_xhr(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_xhr", value)


@pulumi.input_type
class PulsarJobWeightArgs:
    def __init__(__self__, *,
                 default_value: pulumi.Input[float],
                 name: pulumi.Input[str],
                 weight: pulumi.Input[int],
                 maximize: Optional[pulumi.Input[bool]] = None):
        pulumi.set(__self__, "default_value", default_value)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "weight", weight)
        if maximize is not None:
            pulumi.set(__self__, "maximize", maximize)

    @property
    @pulumi.getter(name="defaultValue")
    def default_value(self) -> pulumi.Input[float]:
        return pulumi.get(self, "default_value")

    @default_value.setter
    def default_value(self, value: pulumi.Input[float]):
        pulumi.set(self, "default_value", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def weight(self) -> pulumi.Input[int]:
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: pulumi.Input[int]):
        pulumi.set(self, "weight", value)

    @property
    @pulumi.getter
    def maximize(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "maximize")

    @maximize.setter
    def maximize(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "maximize", value)


@pulumi.input_type
class RecordAnswerArgs:
    def __init__(__self__, *,
                 answer: Optional[pulumi.Input[str]] = None,
                 meta: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 region: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] answer: Space delimited string of RDATA fields dependent on the record type.
               
               A:
               
               answer = "1.2.3.4"
               
               CNAME:
               
               answer = "www.example.com"
               
               MX:
               
               answer = "5 mail.example.com"
               
               SRV:
               
               answer = "10 0 2380 node-1.example.com"
               
               SPF:
               
               answer = "v=DKIM1; k=rsa; p=XXXXXXXX"
        :param pulumi.Input[str] region: The region (Answer Group really) that this answer
               belongs to. This should be one of the names specified in `regions`. Only a
               single `region` per answer is currently supported. If you want an answer in
               multiple regions, duplicating the answer (including metadata) is the correct
               approach.
               * ` meta` - (Optional) meta is supported at the `answer` level. Meta
               is documented below.
        """
        if answer is not None:
            pulumi.set(__self__, "answer", answer)
        if meta is not None:
            pulumi.set(__self__, "meta", meta)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter
    def answer(self) -> Optional[pulumi.Input[str]]:
        """
        Space delimited string of RDATA fields dependent on the record type.

        A:

        answer = "1.2.3.4"

        CNAME:

        answer = "www.example.com"

        MX:

        answer = "5 mail.example.com"

        SRV:

        answer = "10 0 2380 node-1.example.com"

        SPF:

        answer = "v=DKIM1; k=rsa; p=XXXXXXXX"
        """
        return pulumi.get(self, "answer")

    @answer.setter
    def answer(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "answer", value)

    @property
    @pulumi.getter
    def meta(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "meta")

    @meta.setter
    def meta(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "meta", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region (Answer Group really) that this answer
        belongs to. This should be one of the names specified in `regions`. Only a
        single `region` per answer is currently supported. If you want an answer in
        multiple regions, duplicating the answer (including metadata) is the correct
        approach.
        * ` meta` - (Optional) meta is supported at the `answer` level. Meta
        is documented below.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class RecordFilterArgs:
    def __init__(__self__, *,
                 filter: pulumi.Input[str],
                 config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 disabled: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[str] filter: The type of filter.
        :param pulumi.Input[Mapping[str, Any]] config: The filters' configuration. Simple key/value pairs
               determined by the filter type.
        :param pulumi.Input[bool] disabled: Determines whether the filter is applied in the
               filter chain.
        """
        pulumi.set(__self__, "filter", filter)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)

    @property
    @pulumi.getter
    def filter(self) -> pulumi.Input[str]:
        """
        The type of filter.
        """
        return pulumi.get(self, "filter")

    @filter.setter
    def filter(self, value: pulumi.Input[str]):
        pulumi.set(self, "filter", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        The filters' configuration. Simple key/value pairs
        determined by the filter type.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Determines whether the filter is applied in the
        filter chain.
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disabled", value)


@pulumi.input_type
class RecordRegionArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 meta: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        :param pulumi.Input[str] name: Name of the region (or Answer Group).
        """
        pulumi.set(__self__, "name", name)
        if meta is not None:
            pulumi.set(__self__, "meta", meta)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the region (or Answer Group).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def meta(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "meta")

    @meta.setter
    def meta(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "meta", value)


@pulumi.input_type
class TeamDnsRecordsAllowArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[str],
                 include_subdomains: pulumi.Input[bool],
                 type: pulumi.Input[str],
                 zone: pulumi.Input[str]):
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "include_subdomains", include_subdomains)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="includeSubdomains")
    def include_subdomains(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "include_subdomains")

    @include_subdomains.setter
    def include_subdomains(self, value: pulumi.Input[bool]):
        pulumi.set(self, "include_subdomains", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[str]:
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class TeamDnsRecordsDenyArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[str],
                 include_subdomains: pulumi.Input[bool],
                 type: pulumi.Input[str],
                 zone: pulumi.Input[str]):
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "include_subdomains", include_subdomains)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="includeSubdomains")
    def include_subdomains(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "include_subdomains")

    @include_subdomains.setter
    def include_subdomains(self, value: pulumi.Input[bool]):
        pulumi.set(self, "include_subdomains", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[str]:
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class TeamIpWhitelistArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 values: pulumi.Input[Sequence[pulumi.Input[str]]]):
        """
        :param pulumi.Input[str] name: The free form name of the team.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The free form name of the team.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "values", value)


@pulumi.input_type
class UserDnsRecordsAllowArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[str],
                 include_subdomains: pulumi.Input[bool],
                 type: pulumi.Input[str],
                 zone: pulumi.Input[str]):
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "include_subdomains", include_subdomains)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="includeSubdomains")
    def include_subdomains(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "include_subdomains")

    @include_subdomains.setter
    def include_subdomains(self, value: pulumi.Input[bool]):
        pulumi.set(self, "include_subdomains", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[str]:
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class UserDnsRecordsDenyArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[str],
                 include_subdomains: pulumi.Input[bool],
                 type: pulumi.Input[str],
                 zone: pulumi.Input[str]):
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "include_subdomains", include_subdomains)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="includeSubdomains")
    def include_subdomains(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "include_subdomains")

    @include_subdomains.setter
    def include_subdomains(self, value: pulumi.Input[bool]):
        pulumi.set(self, "include_subdomains", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[str]:
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class ZoneSecondaryArgs:
    def __init__(__self__, *,
                 ip: pulumi.Input[str],
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 notify: Optional[pulumi.Input[bool]] = None,
                 port: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] ip: IPv4 address of the secondary server.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] networks: List of network IDs (`int`) for which the zone
               should be made available. Default is network 0, the primary NSONE Global
               Network. Normally, you should not have to worry about this.
        :param pulumi.Input[bool] notify: Whether we send `NOTIFY` messages to the secondary host
               when the zone changes. Default `false`.
        :param pulumi.Input[int] port: Port of the the secondary server. Default `53`.
        """
        pulumi.set(__self__, "ip", ip)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if notify is not None:
            pulumi.set(__self__, "notify", notify)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Input[str]:
        """
        IPv4 address of the secondary server.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[str]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        List of network IDs (`int`) for which the zone
        should be made available. Default is network 0, the primary NSONE Global
        Network. Normally, you should not have to worry about this.
        """
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "networks", value)

    @property
    @pulumi.getter
    def notify(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether we send `NOTIFY` messages to the secondary host
        when the zone changes. Default `false`.
        """
        return pulumi.get(self, "notify")

    @notify.setter
    def notify(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "notify", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        Port of the the secondary server. Default `53`.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)


@pulumi.input_type
class GetMonitoringRegionsRegionArgs:
    def __init__(__self__, *,
                 code: Optional[str] = None,
                 name: Optional[str] = None,
                 subnets: Optional[Sequence[str]] = None):
        """
        :param str code: 3-letter city code identifying the location of the monitor.
        :param str name: City name identifying the location of the monitor.
        :param Sequence[str] subnets: A list of IPv4 and IPv6 subnets the monitor sources requests from.
        """
        if code is not None:
            pulumi.set(__self__, "code", code)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if subnets is not None:
            pulumi.set(__self__, "subnets", subnets)

    @property
    @pulumi.getter
    def code(self) -> Optional[str]:
        """
        3-letter city code identifying the location of the monitor.
        """
        return pulumi.get(self, "code")

    @code.setter
    def code(self, value: Optional[str]):
        pulumi.set(self, "code", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        City name identifying the location of the monitor.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def subnets(self) -> Optional[Sequence[str]]:
        """
        A list of IPv4 and IPv6 subnets the monitor sources requests from.
        """
        return pulumi.get(self, "subnets")

    @subnets.setter
    def subnets(self, value: Optional[Sequence[str]]):
        pulumi.set(self, "subnets", value)


